#pragma once

#include "Renderer.h"



class ColormapRenderer : public Renderer
{
public:

enum DRAW_STYLE
{
	DRAW_POINTS   =0,					//Draw points, color-mapped by their scalar value
	DRAW_C0_CELLS,						//Draw cells, color-mapped by their scalar value (computed by averaging vertex scalars)
	DRAW_C1_CELLS,						//Draw cells, color-mapped by their vertex scalars, using bilinear color interpolation
	DRAW_C1_TEX_CELLS					//Draw cells, color-mapped by their vertex scalars, using bilinear scalar interpolation done by 1D textures
};	


enum COLORMAP_TYPE
{
    COLORMAP_GRAYSCALE =0,				//Classical grayscale (luminance) colormap
	COLORMAP_RAINBOW,					//Classical rainbow colormap
	COLORMAP_SATURATION					//Colormap obtained from all saturation levels of a given hue (green)
};	

				ColormapRenderer(): draw_style(DRAW_POINTS), colormap_type(COLORMAP_GRAYSCALE) 
				{  createTextures(); }

void			setDrawingStyle(DRAW_STYLE s)
				{ draw_style = s; }

void			setColormapType(COLORMAP_TYPE c)
				{ colormap_type = c; }
				
				
void			draw(Grid&);

protected:

DRAW_STYLE		draw_style;
COLORMAP_TYPE	colormap_type;
void			mapToColor(float v,float& R,float& G,float& B);
void			createTextures();

private:

void			drawPoints(Grid& g);
void			drawC0Cells(Grid& g);
void			drawC1Cells(Grid& g);
void			drawC1TexCells(Grid& g);
unsigned int	textureID[3];
};



						

